lxm3.xm\_cluster.ModuleName
===========================

.. currentmodule:: lxm3.xm_cluster

.. autoclass:: ModuleName

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ModuleName.__init__
      ~ModuleName.count
      ~ModuleName.index
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ModuleName.module_name
   
   